==> haskell-safe-exceptions-0.1.7.0-25-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-safe-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: safe-exceptions
version: 0.1.7.0
id: safe-exceptions-0.1.7.0-Htfc5ZFVDIMH89O41bKi9X
key: safe-exceptions-0.1.7.0-Htfc5ZFVDIMH89O41bKi9X
license: MIT
copyright: 2016 FP Complete
maintainer: michael@fpcomplete.com
author: Michael Snoyman
homepage: https://github.com/fpco/safe-exceptions#readme
synopsis: Safe, consistent, and easy exception handling
description:
    Please see README.md
category: Control
abi: b1fe5e3dd687003220bfb83751af314e
exposed: True
exposed-modules:
    Control.Exception.Safe
import-dirs: /usr/lib/ghc-8.4.3/site-local/safe-exceptions-0.1.7.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/safe-exceptions-0.1.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/safe-exceptions-0.1.7.0
hs-libraries: HSsafe-exceptions-0.1.7.0-Htfc5ZFVDIMH89O41bKi9X
depends:
    base-4.11.1.0 deepseq-1.4.3.0
    exceptions-0.10.0-7FqenMMTX3xHtUICKpGQUY transformers-0.5.5.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             exceptions-0.10.0-7FqenMMTX3xHtUICKpGQUY=1e7acabe11915a69b3faf108407a56c7
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
haddock-interfaces: /usr/share/doc/haskell-safe-exceptions/html/safe-exceptions.haddock
haddock-html: /usr/share/doc/haskell-safe-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-safe-exceptions-0.1.7.0-26-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-safe-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: safe-exceptions
version: 0.1.7.0
id: safe-exceptions-0.1.7.0-EajpmZ5dg9yEcdPuineprt
key: safe-exceptions-0.1.7.0-EajpmZ5dg9yEcdPuineprt
license: MIT
copyright: 2016 FP Complete
maintainer: michael@fpcomplete.com
author: Michael Snoyman
homepage: https://github.com/fpco/safe-exceptions#readme
synopsis: Safe, consistent, and easy exception handling
description:
    Please see README.md
category: Control
abi: ebddffc54b34b10ab319e7fbd3b7878d
exposed: True
exposed-modules:
    Control.Exception.Safe
import-dirs: /usr/lib/ghc-8.4.3/site-local/safe-exceptions-0.1.7.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/safe-exceptions-0.1.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/safe-exceptions-0.1.7.0
hs-libraries: HSsafe-exceptions-0.1.7.0-EajpmZ5dg9yEcdPuineprt
depends:
    base-4.11.1.0 deepseq-1.4.3.0
    exceptions-0.10.0-IRO0p79DXGKGDsbbDc50a8 transformers-0.5.5.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             exceptions-0.10.0-IRO0p79DXGKGDsbbDc50a8=e9779fb859fee3584d68df46d12eac41
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
haddock-interfaces: /usr/share/doc/haskell-safe-exceptions/html/safe-exceptions.haddock
haddock-html: /usr/share/doc/haskell-safe-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
